@@ -32,14 +32,19 @@ async def _(bot: Bot, event: GroupMessageEvent):
     """
     /禁 @user 禁言
     """
-    msg = str(event.get_message())
+    msg = str(event.get_message()).replace(" ", "").split("]")
     sb = At(event.json())
     gid = event.group_id
     status = await check_func_status("admin", str(gid))
     if status:
         if sb:
-            if len(msg.split()) > len(sb):
-                time = int(msg.split()[-1:][0])
+            if len(msg) > len(sb):
+                try:
+                    time = int(msg[-1:][0])
+                except ValueError:
+                    for q in sb:
+                        raw_msg = event.raw_message.replace(" ", "").replace(str(q), "")
+                    time = int(''.join(str(num) for num in list(filter(lambda x: x.isdigit(), raw_msg))))
                 baning = banSb(gid, ban_list=sb, time=time)
                 async for baned in baning:
                     if baned:
@@ -87,11 +92,11 @@ async def _(bot: Bot, event: GroupMessageEvent):
                     try:
                         await baned
                     except ActionFailed:
-                        await ban.finish("权限不足")
+                        await unban.finish("权限不足")
                     else:
                         logger.info("解禁操作成功")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await unban.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 ban_all = on_command("/all", permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=1, block=True)
@@ -115,7 +120,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             enable=enable
         )
     except ActionFailed:
-        await ban.finish("权限不足")
+        await ban_all.finish("权限不足")
     else:
         logger.info(f"全体操作成功 {str(enable)}")
 
@@ -147,7 +152,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 logger.info("改名片操作成功")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await change.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 title = on_command('头衔', permission=SUPERUSER | GROUP_OWNER, priority=1, block=True)
@@ -182,7 +187,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await title.finish("未填写头衔名称 或 不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await title.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 title_ = on_command('删头衔', permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=1, block=True)
@@ -217,7 +222,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await title_.finish("有什么输入错误 或 不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await title_.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 kick = on_command('踢', permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=1, block=True)
@@ -249,7 +254,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await kick.finish("不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await kick.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 kick_ = on_command('黑', permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER, priority=1, block=True)
@@ -281,7 +286,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await kick_.finish("不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await kick_.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 set_g_admin = on_command("管理员+", permission=SUPERUSER | GROUP_OWNER, priority=1, block=True)
@@ -317,7 +322,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await set_g_admin.finish("指令不正确 或 不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await set_g_admin.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 unset_g_admin = on_command("管理员-", permission=SUPERUSER | GROUP_OWNER, priority=1, block=True)
@@ -353,7 +358,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
             else:
                 await unset_g_admin.finish("指令不正确 或 不能含有@全体成员")
     else:
-        await ban.send(f"功能处于关闭状态，发送【开关管理】开启")
+        await unset_g_admin.send(f"功能处于关闭状态，发送【开关管理】开启")
 
 
 __usage__ = """
@@ -364,6 +369,7 @@ __usage__ = """
 权限：permission=SUPERUSER | GROUP_ADMIN | GROUP_OWNER
   禁言:
     禁 @某人 时间（s）[1,2591999]
+    禁 时间（s）@某人 [1,2591999]
     禁 @某人 缺省时间则随机
     禁 @某人 0 可解禁
     解 @某人
@@ -416,7 +422,8 @@ __usage__ = """
 【被动识别】
 涩图检测：将禁言随机时间
 
-违禁词检测：将禁言随机时间
+违禁词检测：已支持正则表达式，可定义触发违禁词操作(默认为禁言+撤回)
+定义操作方法：用制表符分隔，左边为触发条件，右边为操作定义($禁言、$撤回)
 群内发送：
   简单违禁词 ：简单级别过滤
   严格违禁词 ：严格级别过滤(不建议)
