@@ -62,7 +62,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     else:
         await word_start.finish("请先发送【开关群词云】开启此功能")
 
-word = on_message(priority=10)
+word = on_message(priority=10, block=False)
 
 
 @word.handle()
@@ -81,7 +81,7 @@ async def _(bot: Bot, event: GroupMessageEvent):
     txt = open(word_path, "r", encoding="utf-8").read().split("\n")
     if gid in txt:
         msg = await replace_tmr(msg)
-        with open(path_temp, "a+") as c:
+        with open(path_temp, "a+" ,encoding="utf-8") as c:
             c.write(msg + "\n")
 
 
